bayespy.utils.random
====================

.. automodule:: bayespy.utils.random

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree: generated/
   
      alpha_beta_recursion
      bernoulli
      categorical
      correlation
      covariance
      dirichlet
      gamma_entropy
      gamma_logpdf
      gaussian_entropy
      gaussian_gamma_to_t
      gaussian_logpdf
      intervals
      invwishart_rand
      logodds_to_probability
      mask
      orth
      sphere
      svd
      t_logpdf
      wishart
      wishart_rand
   
   

   
   
   

   
   
   